=======
Credits
=======

Maintainers
----------------

* João Luiz Lorencetti - `@jllorencetti`_

Contributors
------------

* Jair Henrique - `@jairhenrique`_

.. _`@jllorencetti`: https://github.com/jllorencetti
.. _`@jairhenrique`: https://github.com/jairhenrique